@@ -1,8 +1,8 @@
 from converter.config.config_converter import excluded_fields, base_converter_params
 import logging
 import sys
-import warnings
 import sqlalchemy
+import warnings
 from sqlalchemy.engine import create_engine
 from sqlalchemy import MetaData, Table
 from converter.vertica.custom_insert import vertica_insert
@@ -10,18 +10,6 @@ from converter.vertica.merge import vertica_merge
 
 warnings.filterwarnings("ignore")
 
-logging.basicConfig(
-    stream=sys.stdout,
-    level=logging.INFO,
-    format="%(asctime)s  %(name)s  %(levelname)s: %(message)s",
-)
-logging.basicConfig(
-    stream=sys.stderr,
-    level=logging.ERROR,
-    format="%(asctime)s  %(name)s  %(levelname)s: %(message)s",
-)
-logging.captureWarnings(True)
-
 
 def get_type_sql_alchemy(type):
     try:
@@ -46,15 +34,19 @@ def get_default_arg_sql_alchemy(column):
 
 class DataBaseWorker:
     def __init__(
-        self, sql_credentials, db, debug=True, tables=None, table_checker=True
+            self, sql_credentials, db, debug=True, tables=None, table_checker=True
     ):
         """
         :param sql_credentials:
-        :param from_db:
-        :param to_db:
         :param debug: show debug text
         :param tables: converter only for list of tables. Will process more rapidly
         """
+        log_format = "%(asctime)-15s %(name)s:%(levelname)s: %(message)s"
+        logging.basicConfig(format=log_format, stream=sys.stdout, level=logging.INFO)
+        logging.basicConfig(format=log_format, stream=sys.stderr, level=logging.ERROR)
+        logging.captureWarnings(True)
+        self.logger = logging.getLogger(__class__.__name__)
+
         self.table_checker = table_checker
         self.tables = tables or []
         self.table_name = None
@@ -81,9 +73,9 @@ class DataBaseWorker:
             self.schema = self.cred["schema"]
         else:
             self.schema = self.cred["database"]
-        self.log("try to connect...")
+        self.logger.info("try to connect...")
         self.conn = self.engine.connect()
-        self.log("connecting is successfull")
+        self.logger.info("connecting is successful")
 
     def __del__(self):
         if self.conn is not None:
@@ -119,7 +111,7 @@ class DataBaseWorker:
             try:
                 meta.reflect(only=tables)
             except sqlalchemy.exc.InvalidRequestError:
-                self.log(
+                self.logger.error(
                     "One or more file didn't find in database {}. Load table later".format(
                         self.db
                     )
@@ -145,10 +137,6 @@ class DataBaseWorker:
     def __repr__(self):
         return "DataBaseWorker_{}".format(self.db)
 
-    def log(self, text):
-        if self.debug:
-            logging.info(self.__str__ + ": " + text)
-
     def check_if_table_availible(self, table):
         if len(self.tables) > 0 and table not in self.tables:
             raise ModuleNotFoundError(
@@ -192,14 +180,14 @@ class DataBaseWorker:
         )
 
     def insert_merge_vertica(
-        self,
-        table_name,
-        data,
-        staging_schema=None,
-        schema=None,
-        staging_table_suffix=None,
-        key_fields=None,
-        filter_merge_fields=None,
+            self,
+            table_name,
+            data,
+            staging_schema=None,
+            schema=None,
+            staging_table_suffix=None,
+            key_fields=None,
+            filter_merge_fields=None,
     ):
         """
         Insert and update data in target table using temporary staging table, only for vertica
@@ -225,7 +213,7 @@ class DataBaseWorker:
         sql_create_staging = "create table {staging_table_name} like {schema}.{table_name}".format(
             staging_table_name=staging_table_name, table_name=table_name, schema=schema
         )
-        self.log(sql_create_staging)
+        self.logger.info(sql_create_staging)
         self.conn.execute(sql_create_staging)
         try:
             self.insert_vertica(
@@ -234,7 +222,7 @@ class DataBaseWorker:
                 schema=staging_schema,
                 table_suffix=staging_table_suffix,
             )
-            self.log(
+            self.logger.info(
                 vertica_merge(
                     conn=self.conn,
                     table_name=schema + "." + table_name,
@@ -248,7 +236,7 @@ class DataBaseWorker:
             sql_drop = "drop table {staging_table_name} cascade".format(
                 staging_table_name=staging_table_name
             )
-            self.log(sql_drop)
+            self.logger.info(sql_drop)
             self.conn.execute(sql_drop)
 
     def get_table_schema(self, table_name):
